# EVOVAQ [![Made at Quasar!](https://img.shields.io/badge/Unina-%20QuasarLab-blue)](http://quasar.unina.it) [![Made at Quasar!](https://img.shields.io/badge/Documentation-%20Readthedocs-brightgreen)](https://evovaq.readthedocs.io/en/latest/index.html)

**EVOlutionary algorithms-based toolbox for VAriational Quantum circuits (EVOVAQ)** is a novel evolutionary framework designed
to easily train variational quantum circuits through evolutionary techniques, and to have a simple interface between
these algorithms and quantum libraries, such as Qiskit.

**Optimizers in EVOVAQ:**

* Genetic Algorithm

* Differential Evolution

* Memetic Algorithm

* Big Bang Big Crunch

* Particle Swarm Optimization

* CHC Algorithm

* Hill Climbing

## Installation

You can install EVOVAQ via ``pip``:

```bash
pip install evovaq
```

Pip will handle all dependencies automatically and you will always install the latest version.
